@@ -9,9 +9,11 @@
 
 use icu::calendar::Gregorian;
 use icu::datetime::DateTimeFormatOptions;
-use icu::locid::{macros::langid, Locale};
-use icu::plurals::{PluralCategory, PluralRuleType, PluralRules};
-use icu_datetime::{mock::zoned_datetime::MockZonedDateTime, ZonedDateTimeFormat};
+use icu::locid::{locale, Locale};
+use icu::plurals::{PluralCategory, PluralRules};
+use icu_datetime::{
+    mock::zoned_datetime::MockZonedDateTime, TimeZoneFormatOptions, ZonedDateTimeFormat,
+};
 use icu_uniset::UnicodeSetBuilder;
 use std::env;
 
@@ -22,14 +24,14 @@ fn print<T: AsRef<str>>(_input: T) {
 
 #[no_mangle]
 fn main(_argc: isize, _argv: *const *const u8) -> isize {
-    let provider = icu_testdata::get_static_provider();
+    let provider = icu_testdata::get_provider();
 
     let args: Vec<String> = env::args().collect();
 
     let locale: Locale = args
         .get(1)
-        .map(|s| s.parse().expect("Failed to parse language identifier"))
-        .unwrap_or_else(|| langid!("en").into());
+        .map(|s| s.parse().expect("Failed to parse locale"))
+        .unwrap_or_else(|| locale!("en"));
 
     let user_name = args.get(2).cloned().unwrap_or_else(|| "John".to_string());
 
@@ -50,6 +52,7 @@ fn main(_argc: isize, _argv: *const *const u8) -> isize {
             &provider,
             &provider,
             &DateTimeFormatOptions::default(),
+            &TimeZoneFormatOptions::default(),
         )
         .expect("Failed to create DateTimeFormat.");
         let today: MockZonedDateTime = "2020-10-10T18:56:00Z"
@@ -77,8 +80,7 @@ fn main(_argc: isize, _argv: *const *const u8) -> isize {
     }
 
     {
-        let en = langid!("en");
-        let pr = PluralRules::try_new(en, &provider, PluralRuleType::Cardinal)
+        let pr = PluralRules::try_new_cardinal(locale!("en"), &provider)
             .expect("Failed to create PluralRules.");
 
         match pr.select(email_count) {
