@@ -38,36 +38,26 @@
 //! ICU4X components share a set of common features that control whether core pieces of
 //! functionality are compiled. These features are:
 //!
-//! - `provider_serde`: Whether to include Serde Serialize/Deserialize implementations for
-//!   ICU4X locale data structs, such as [`SymbolsV1`]. (On by default)
-//! - `serde`: Whether to include Serde Serialize/Deserialize implementations for core libary
-//!   types, such as [`Locale`].
+//! - `serialize`: Whether to include Serde Deserialize implementations for
+//!   ICU4X locale data structs, such as [`SymbolsV1`], and Serialize/Deserialize implementations
+//!   for core libary types, such as [`Locale`] (On by default)
+//! - `datagen`: Whether to include Serde Serialize and other data generation traits for ICU4X locale data structs.
 //! - `bench`: Whether to enable exhaustive benchmarks. This can be enabled on individual crates
 //!   when running `cargo bench`.
 //! - `experimental`: Whether to enable experimental preview features. Modules enabled with
 //!   this feature may not be production-ready and could change at any time.
-//! - `provider_transform_internals`: This is code that is useful for transforming CLDR data, but
-//!   may be risky to ship as a public API. For instance in DateTimeFormat code we may want to
-//!   manipulate patterns, but not allow end users to do the same.
 //!
 //! # Example
 //!
 //! ```
-//! use icu::locid::Locale;
-//! use icu::locid::macros::langid;
+//! use icu::locid::locale;
 //! use icu::datetime::{DateTimeFormat, options::length, mock::parse_gregorian_from_str};
 //!
 //! let provider = icu_testdata::get_provider();
 //!
-//! let locale: Locale = langid!("en").into();
+//! let options = length::Bag::from_date_time_style(length::Date::Long, length::Time::Medium).into();
 //!
-//! let options = length::Bag {
-//!     date: Some(length::Date::Long),
-//!     time: Some(length::Time::Medium),
-//!     ..Default::default()
-//! }.into();
-//!
-//! let dtf = DateTimeFormat::try_new(locale, &provider, &options)
+//! let dtf = DateTimeFormat::try_new(locale!("en"), &provider, &options)
 //!     .expect("Failed to create DateTimeFormat instance.");
 //!
 //! let date = parse_gregorian_from_str("2020-09-12T12:35:00")
@@ -83,7 +73,17 @@
 //! [`Locale`]: crate::locid::Locale
 //! [`SymbolsV1`]: crate::decimal::provider::DecimalSymbolsV1
 
+// https://github.com/unicode-org/icu4x/blob/main/docs/process/boilerplate.md#library-annotations
 #![cfg_attr(not(any(test, feature = "std")), no_std)]
+#![cfg_attr(
+    not(test),
+    deny(
+        clippy::indexing_slicing,
+        clippy::unwrap_used,
+        clippy::expect_used,
+        clippy::panic
+    )
+)]
 
 pub mod calendar {
     //! Contains the core types used by ICU4X for dealing
@@ -111,21 +111,13 @@ pub mod datetime {
     //! # Examples
     //!
     //! ```
-    //! use icu::locid::Locale;
-    //! use icu::locid::macros::langid;
+    //! use icu::locid::locale;
     //! use icu::datetime::{DateTimeFormat, options::length, mock::parse_gregorian_from_str};
     //!
     //! let provider = icu_testdata::get_provider();
     //!
-    //! let locale: Locale = langid!("en").into();
-    //!
-    //! let options = length::Bag {
-    //!     date: Some(length::Date::Medium),
-    //!     time: Some(length::Time::Short),
-    //!     ..Default::default()
-    //! }.into();
-    //!
-    //! let dtf = DateTimeFormat::try_new(locale, &provider, &options)
+    //! let options = length::Bag::from_date_time_style(length::Date::Medium, length::Time::Short).into();
+    //! let dtf = DateTimeFormat::try_new(locale!("en"), &provider, &options)
     //!     .expect("Failed to create DateTimeFormat instance.");
     //!
     //! let date = parse_gregorian_from_str("2020-09-12T12:35:00")
@@ -152,18 +144,16 @@ pub mod decimal {
     //!
     //! ```
     //! use icu::decimal::FixedDecimalFormat;
-    //! use icu::locid::Locale;
-    //! use icu::locid::macros::langid;
+    //! use icu::locid::locale;
     //! use writeable::Writeable;
     //!
-    //! let locale: Locale = langid!("bn").into();
     //! let provider = icu_testdata::get_provider();
-    //! let fdf = FixedDecimalFormat::try_new(locale, &provider, Default::default())
+    //! let fdf = FixedDecimalFormat::try_new(locale!("bn"), &provider, Default::default())
     //!     .expect("Data should load successfully");
     //!
     //! let fixed_decimal = 1000007.into();
     //! let formatted_value = fdf.format(&fixed_decimal);
-    //! let formatted_str = formatted_value.writeable_to_string();
+    //! let formatted_str = formatted_value.write_to_string();
     //!
     //! assert_eq!("১০,০০,০০৭", formatted_str);
     //! ```
@@ -176,16 +166,15 @@ pub mod decimal {
     //! use icu::locid::Locale;
     //! use writeable::Writeable;
     //!
-    //! let locale = Locale::und();
     //! let provider = icu_provider::inv::InvariantDataProvider;
-    //! let fdf = FixedDecimalFormat::try_new(locale, &provider, Default::default())
+    //! let fdf = FixedDecimalFormat::try_new(Locale::UND, &provider, Default::default())
     //!     .expect("Data should load successfully");
     //!
     //! let fixed_decimal = FixedDecimal::from(200050)
     //!     .multiplied_pow10(-2)
     //!     .expect("Operation is fully in range");
     //!
-    //! assert_eq!("2,000.50", fdf.format(&fixed_decimal).writeable_to_string());
+    //! assert_eq!("2,000.50", fdf.format(&fixed_decimal).write_to_string());
     //! ```
     //!
     //! [`FixedDecimal`]: fixed_decimal::FixedDecimal
@@ -265,23 +254,16 @@ pub mod locid {
     //! # Examples
     //!
     //! ```
-    //! use icu::locid::Locale;
-    //! use icu::locid::subtags::{Language, Region};
+    //! use icu::locid::{language, locale, region};
     //!
-    //! let mut loc: Locale = "en-US".parse()
-    //!     .expect("Parsing failed.");
+    //! let mut loc = locale!("en-US").clone();
     //!
-    //! let lang: Language = "en".parse()
-    //!     .expect("Parsing failed.");
-    //! let region: Region = "US".parse()
-    //!     .expect("Parsing failed.");
-    //!
-    //! assert_eq!(loc.id.language, lang);
+    //! assert_eq!(loc.id.language, language!("en"));
     //! assert_eq!(loc.id.script, None);
-    //! assert_eq!(loc.id.region, Some(region));
+    //! assert_eq!(loc.id.region, Some(region!("US")));
     //! assert_eq!(loc.id.variants.len(), 0);
     //!
-    //! let region: Region = "GB".parse().expect("Parsing failed.");
+    //! let region = region!("GB");
     //! loc.id.region = Some(region);
     //!
     //! assert_eq!(loc.to_string(), "en-GB");
@@ -293,10 +275,6 @@ pub mod locid {
     //! [`ICU4X`]: https://github.com/unicode-org/icu4x
     //! [`Unicode Extensions`]: extensions
     pub use icu_locid::*;
-
-    pub mod macros {
-        pub use icu_locid_macros::*;
-    }
 }
 
 pub mod plurals {
@@ -322,14 +300,12 @@ pub mod plurals {
     //! # Examples
     //!
     //! ```
-    //! use icu::locid::macros::langid;
+    //! use icu::locid::locale;
     //! use icu::plurals::{PluralRules, PluralRuleType, PluralCategory};
     //!
-    //! let lid = langid!("en");
-    //!
     //! let provider = icu_testdata::get_provider();
     //!
-    //! let pr = PluralRules::try_new(lid, &provider, PluralRuleType::Cardinal)
+    //! let pr = PluralRules::try_new(locale!("en"), &provider, PluralRuleType::Cardinal)
     //!     .expect("Failed to construct a PluralRules struct.");
     //!
     //! assert_eq!(pr.select(5_usize), PluralCategory::Other);
@@ -382,7 +358,7 @@ pub mod properties {
     //! ## Property data as `UnicodeSet`s
     //!
     //! ```
-    //! use icu::properties::{sets, GeneralCategory};
+    //! use icu::properties::{maps, sets, GeneralCategory};
     //!
     //! let provider = icu_testdata::get_provider();
     //!
@@ -399,11 +375,10 @@ pub mod properties {
     //!
     //! // An individual enumerated property value as a `UnicodeSet`
     //!
-    //! let payload =
-    //!     sets::get_for_general_category(&provider, GeneralCategory::LineSeparator)
-    //!         .expect("The data should be valid");
+    //! let payload = maps::get_general_category(&provider).expect("The data should be valid");
     //! let data_struct = payload.get();
-    //! let line_sep = &data_struct.inv_list;
+    //! let gc = &data_struct.code_point_trie;
+    //! let line_sep = gc.get_set_for_value(GeneralCategory::LineSeparator);
     //!
     //! assert!(line_sep.contains_u32(0x2028));
     //! assert!(!line_sep.contains_u32(0x2029));
@@ -426,6 +401,48 @@ pub mod properties {
     //! assert_eq!(script.get('木' as u32), Script::Han);  // U+6728
     //! ```
     //!
+    //! ## Property data for `Script` and `Script_Extensions`
+    //!
+    //! ```
+    //! use icu::properties::{script, Script};
+    //!
+    //! let provider = icu_testdata::get_provider();
+    //!
+    //! let payload =
+    //!     script::get_script_with_extensions(&provider)
+    //!         .expect("The data should be valid");
+    //! let data_struct = payload.get();
+    //! let swe = &data_struct.data;
+    //!
+    //! // get the `Script` property value
+    //! assert_eq!(swe.get_script_val(0x0650), Script::Inherited); // U+0650 ARABIC KASRA
+    //! assert_eq!(swe.get_script_val(0x0660), Script::Arabic); // U+0660 ARABIC-INDIC DIGIT ZERO
+    //!
+    //! // get the `Script_Extensions` property value
+    //! assert_eq!(
+    //!     swe.get_script_extensions_val(0x0640) // U+0640 ARABIC TATWEEL
+    //!         .iter().collect::<Vec<Script>>(),
+    //!     vec![Script::Arabic, Script::Syriac, Script::Mandaic, Script::Manichaean,
+    //!          Script::PsalterPahlavi, Script::Adlam, Script::HanifiRohingya, Script::Sogdian,
+    //!          Script::OldUyghur]
+    //! );
+    //! assert_eq!(
+    //!     swe.get_script_extensions_val('௫' as u32) // U+0BEB TAMIL DIGIT FIVE
+    //!         .iter().collect::<Vec<Script>>(),
+    //!     vec![Script::Tamil, Script::Grantha]
+    //! );
+    //!
+    //! // check containment of a `Script` value in the `Script_Extensions` value
+    //! // U+0650 ARABIC KASRA
+    //! assert!(swe.has_script(0x0650, Script::Arabic));
+    //! assert!(swe.has_script(0x0650, Script::Syriac));
+    //!
+    //! // get a `UnicodeSet` for when `Script` value is contained in `Script_Extensions` value
+    //! let syriac = swe.get_script_extensions_set(Script::Syriac);
+    //! assert!(syriac.contains_u32(0x0650)); // ARABIC KASRA
+    //! assert!(!syriac.contains_u32(0x0660)); // ARABIC-INDIC DIGIT ZERO
+    //! ```
+    //!
     //! [`ICU4X`]: ../icu/index.html
     //! [Unicode Properties]: https://unicode-org.github.io/icu/userguide/strings/properties.html
     //! [`UnicodeSet`]: ../../icu_uniset/struct.UnicodeSet.html
@@ -434,3 +451,47 @@ pub mod properties {
     //! [`maps`]: maps
     pub use icu_properties::*;
 }
+
+pub mod list {
+    //! List formatting
+    //!
+    //! This API provides the [`ListFormatter`] which renders sequences of [`Writeable`](
+    //! writeable::Writeable)s as lists in a locale-sensitive way.
+    //!
+    //! # Examples
+    //!
+    //! ## Format a list of strings in Spanish
+    //!
+    //! ```
+    //! use icu::list::{ListFormatter, ListStyle};
+    //! use icu::locid::locale;
+    //! use writeable::Writeable;
+    //!
+    //! let provider = icu_testdata::get_provider();
+    //! let list_formatter = ListFormatter::try_new_and(locale!("es"), &provider, ListStyle::Wide)
+    //!     .expect("Data should load successfully");
+    //!
+    //! assert_eq!(
+    //!     list_formatter.format(["España", "Suiza"].iter())
+    //!         .write_to_string(),
+    //!     "España y Suiza"
+    //! );
+    //!
+    //! // The Spanish 'y' sometimes becomes an 'e':
+    //! assert_eq!(
+    //!     list_formatter.format(["España", "Suiza", "Italia"].iter())
+    //!         .write_to_string(),
+    //!     "España, Suiza e Italia"
+    //! );
+    //!
+    //! // We can use any Writeables as inputs:
+    //! assert_eq!(
+    //!     list_formatter.format(1..=10).write_to_string(),
+    //!     "1, 2, 3, 4, 5, 6, 7, 8, 9 y 10"
+    //! );
+    //!```
+    //!
+    //! [`ListFormatter`]: ListFormatter
+
+    pub use icu_list::*;
+}
